import _extends from "@babel/runtime/helpers/esm/extends";
import _objectWithoutPropertiesLoose from "@babel/runtime/helpers/esm/objectWithoutPropertiesLoose";
import { amber, green } from "@material-ui/core/colors";
import IconButton from "@material-ui/core/IconButton";
import Slide from "@material-ui/core/Slide";
import { default as MatSnackbar } from "@material-ui/core/Snackbar"; // import CheckCircleIcon from "@material-ui/icons/CheckCircle";
// import CloseIcon from "@material-ui/icons/Close";
// import ErrorIcon from "@material-ui/icons/Error";
// import InfoIcon from "@material-ui/icons/Info";
// import WarningIcon from "@material-ui/icons/Warning";

import clsx from "clsx";
import PropTypes from "prop-types";
import React, { memo } from "react";
import makeStyles from "../styles/makeStyles";
const useStyles = makeStyles(theme => ({
  root: {
    backgroundColor: "#FFFFFF",
    color: theme.palette.text.primary
  },
  success: {
    borderLeft: `8px solid ${green[600]}`
  },
  error: {
    borderLeft: `8px solid ${theme.palette.error.dark}`
  },
  info: {
    borderLeft: `8px solid ${theme.palette.primary.main}`
  },
  warning: {
    borderLeft: `8px solid ${amber[700]}`
  },
  icon: {
    fontSize: 20
  },
  iconvariant: {
    opacity: 0.9,
    marginRight: theme.spacing(2)
  },
  iconsuccess: {
    color: green[600]
  },
  iconerror: {
    color: theme.palette.error.dark
  },
  iconinfo: {
    color: theme.palette.primary.main
  },
  iconwarning: {
    color: amber[700]
  },
  message: {
    display: "flex",
    alignItems: "center"
  }
})); // const variantIcon = {
//   success: CheckCircleIcon,
//   warning: WarningIcon,
//   error: ErrorIcon,
//   info: InfoIcon
// };

const Snackbar = (_ref) => {
  let {
    className,
    message,
    variant
  } = _ref,
      props = _objectWithoutPropertiesLoose(_ref, ["className", "message", "variant"]);

  const classes = useStyles();

  const transition = props => React.createElement(Slide, _extends({}, props, {
    direction: "left"
  })); // const Icon = variantIcon[variant];


  const Icon = () => React.createElement(React.Fragment, null);

  return React.createElement(MatSnackbar, _extends({
    anchorOrigin: {
      vertical: "top",
      horizontal: "right"
    },
    autoHideDuration: 4000,
    TransitionComponent: transition,
    ContentProps: {
      className: clsx(classes[variant], classes.root, className)
    },
    message: React.createElement("span", {
      id: "client-snackbar",
      className: classes.message
    }, React.createElement(Icon, {
      className: clsx(classes.icon, classes[`icon${variant}`], classes.iconVariant)
    }), message),
    action: [React.createElement(IconButton, {
      key: "close",
      "aria-label": "close",
      color: "inherit",
      onClick: props.onClose
    }, "X")]
  }, props));
};

process.env.NODE_ENV !== "production" ? Snackbar.propTypes = {
  className: PropTypes.string,
  message: PropTypes.string.isRequired,
  variant: PropTypes.oneOf(["error", "info", "success", "warning"])
} : void 0;
Snackbar.defaultProps = {
  variant: "success"
};
const memoSnackbar = memo(Snackbar);
export default memoSnackbar;